@@ -24,33 +24,38 @@
 
 #include "decorators.h"
 
+#include <string>
+
+using std::string;
+
 class CharTranslator;
 
 class TagDecorator : public TextDecorator
 {
  protected:
-  char *tag ;
-  char *attr ;
-  char *val ;
+  string tag ;
+  string attr ;
+  string val ;
 
  public:
-  TagDecorator( TextGenerator *t, CharTranslator *, 
-                char *ta, char *a = 0, char *v = 0 );
+  TagDecorator( TextGenerator *t, CharTranslator *,
+                const string &ta, const string &a = "",
+                const string &v = "" );
   virtual ~TagDecorator() {}
   
   virtual void startDecorate();
   virtual void endDecorate();
 
  protected:
-  void startTAG( char *tag, char *attr, char *val ) const;
-  void endTAG( char *tag ) const;
+  void startTAG( ) const;
+  void endTAG( ) const;
   virtual void generateAttrVal() const;
 } ;
 
 class ColorDecorator : public TagDecorator
 {
  public:
-  ColorDecorator( TextGenerator *t, CharTranslator *, char *color );
+  ColorDecorator( TextGenerator *t, CharTranslator *, const string &color );
 } ;
 
 #endif
