@@ -25,8 +25,9 @@
 // for globals
 #include "globalostream.h"
 
-XhtmlTagDecorator::XhtmlTagDecorator( TextGenerator *t, CharTranslator *ct, 
-                                      char *ta, char *a, char *v ) :
+XhtmlTagDecorator::XhtmlTagDecorator( TextGenerator *t, CharTranslator *ct,
+                                      const string &ta, const string &a,
+                                      const string &v ) :
   TagDecorator (t, ct, ta, a, v)
 {
 }
@@ -39,7 +40,7 @@ XhtmlTagDecorator::generateAttrVal() const
 
 // XhtmlColorDecorator
 XhtmlColorDecorator::XhtmlColorDecorator( TextGenerator *t, CharTranslator *tr,
-                                          char *color ) :
+                                          const string &color ) :
   XhtmlTagDecorator( t, tr, SPAN_TAG, COLOR_TAG, color )
 {
 }
