@@ -17,9 +17,6 @@
  *
  */
 
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
 #include <iostream>
 #include <fstream>
 
@@ -30,124 +27,112 @@
 #include "fileutil.h"
 #include "my_string.h"
 
-using std::cerr;
-using std::endl;
-using std::ifstream;
+using namespace std;
 
-static void file_error(const char *error, char *file);
-static void internal_error(const char *error);
+static void file_error(const string &error, const string &file);
+static void internal_error(const string &error);
 
 char *
-read_file(char *fileName)
+read_file(const string &fileName)
 {
-  FILE *file;
   char *buffer = 0;
   long int char_count;
 
   // we open it as binary otherwise we may experience problems under
   // Windows system: when we fread, the number of char read can be
   // less then char_count, and thus we'd get an error...
-  if ( (file = fopen(fileName,"rb") ) == 0 )	// The file does not exist :(
+  ifstream file (fileName.c_str (), ios_base::binary);
+  if (! file.is_open () )
     file_error ("Error operning", fileName);
   else
     {
       // let's go to the end of the file...
-      if (fseek (file, 0, SEEK_END) != 0)
+      file.seekg (0, ios::end);
+      if (! file)
         file_error ("Error positioning", fileName);
 
       // ...to read the dimension
-      char_count = ftell (file);
-      if (char_count < 0)
+      char_count = file.tellg ();
+      if (! file)
         file_error ("Error reading position", fileName);
 
-      buffer = (char *) malloc (char_count +1);
+      buffer = new char [char_count + 1];
       if (! buffer)
         internal_error ("Memory allocation failed");
-
-      // let's go back to the start
-      rewind (file);
-
-      if (fread ((void *) buffer, 1, char_count, file) < (size_t) char_count)
-        file_error ("read error", fileName);
+      
+      file.seekg (0, ios::beg);
+      if (! file)
+        file_error ("Error positioning to start", fileName);
+        
+      //copy file into memory
+      file.read (buffer, char_count);
       buffer[char_count] = '\0';
 
-      fclose (file);
+      file.close ();
     }
 
   return buffer;
 }
 
 void
-file_error(const char *error, char *file)
+file_error(const string &error, const string &file)
 {
   cerr << PACKAGE << ": " << error << ", file " << file << endl;
   exit (1);
 }
 
 void
-internal_error(const char *error)
+internal_error(const string &error)
 {
   cerr << PACKAGE << ": Internal error: " << error << endl;
   exit (1);
 }
 
 // output file name = <outputDir> + input file name + ext
-char *
-createOutputFileName( char *inputFileName, char *outputDir, const char *ext )
+string
+createOutputFileName(const string &inputFileName, char *outputDir, const string &ext )
 {
-  char *input_file_name;
+  string input_file_name;
   char path_separator = '/';
 
   if (! outputDir)
     input_file_name = inputFileName;
   else
     {
-      char *file_name; // without the path
-      file_name = strrchr (inputFileName, '/');
+      string::size_type pos_of_sep;
+      pos_of_sep = inputFileName.find_last_of('/');
       
-      if (! file_name) // try with DOS separator
+      if (pos_of_sep == string::npos) // try with DOS separator
         {
-          file_name = strrchr (inputFileName, '\\');
-          if (file_name)
+  	  pos_of_sep = inputFileName.find_last_of ('\\');
+          if (pos_of_sep != string::npos)
             path_separator = '\\';
         }
 
 
-      if (file_name)
-        input_file_name = &file_name[1];
+      if (pos_of_sep != string::npos)
+        input_file_name = inputFileName.substr (pos_of_sep + 1);
       else
         input_file_name = inputFileName;
     }
 
-  int lenght =  strlen(input_file_name) + 
-    strlen(ext) + 1 ;
-  int output_dir_lenght = 0;
-  
-  if (outputDir)
-    {
-      output_dir_lenght = strlen (outputDir);
-      lenght += output_dir_lenght + 1; // one is for the additional /
-    }
-
-  char *outputFileName = new char[lenght] ;
-  outputFileName[0] = '\0';
+  string outputFileName;
 
   if (outputDir)
     {
-      strcat (outputFileName, outputDir);
-      outputFileName[output_dir_lenght] = path_separator;
-      outputFileName[output_dir_lenght + 1] = '\0';
+      outputFileName += outputDir;
+      outputFileName += path_separator;
     }
-  strcat (outputFileName, input_file_name);
-  strcat (outputFileName, ext);
+  outputFileName += input_file_name;
+  outputFileName += ext;
 
-  return outputFileName ;
+  return outputFileName;
 }
 
 unsigned int
-get_line_count(char *file_name)
+get_line_count(const string &file_name)
 {
-  ifstream input (file_name);
+  ifstream input (file_name.c_str ());
 
   if (! input)
     file_error ("Error opening", file_name);
@@ -176,3 +161,16 @@ get_line_count(istream &input)
 
   return count;
 }
+
+string
+get_file_extension(const string &s)
+{
+  string::size_type pos_of_sep;
+
+  pos_of_sep = s.rfind(".");
+
+  if (pos_of_sep == string::npos)
+    return ""; // no extension
+
+  return s.substr (pos_of_sep + 1);
+}
