@@ -31,16 +31,20 @@
 #include "generators.h"
 #include "globalcolormap.h"
 
-GeneratorFactory::GeneratorFactory(bool line_number, const string &t) :
-  char_translator (0), line_number_option (line_number), title (t)
+GeneratorFactory::GeneratorFactory(bool line_number,
+                                   const string &t,
+                                   bool line_ref) :
+  char_translator (0), line_number_option (line_number), 
+  gen_line_ref (line_ref), title (t)
 {
+  line_number_option = (line_number_option || gen_line_ref);
 }
 
 template <class Decorator>
 void
 GeneratorFactory::decorate_generator(TextGenerator *&decorated)
 {
-  decorated = new Decorator (decorated, char_translator);
+  decorated = new Decorator (decorated, char_translator, gen_line_ref);
 }
 
 template <class Decorator>
@@ -71,7 +75,8 @@ GeneratorFactory::createGenerators()
 
   if (line_number_option)
     {
-      GlobalGenerator = new LineNumberDecorator (GlobalGenerator, char_translator);
+      GlobalGenerator = new LineNumberDecorator
+        (GlobalGenerator, char_translator, gen_line_ref);
       final_decorator = new TextGenerator (char_translator);
     }
   else
