@@ -36,6 +36,7 @@ class GeneratorFactory
  protected:
   CharTranslator *char_translator; // translator of special characters
   bool line_number_option; // whether line number option is given
+  bool gen_line_ref; // whether line numbers are added an anchor
   string title;
 
   virtual TextGenerator *createBoldDecorator(TextGenerator *) = 0;
@@ -45,7 +46,8 @@ class GeneratorFactory
                                               const string &color) = 0;
 
   virtual ColorMap *createColorMap() = 0;
-  virtual TextGenerator *createGenerator(TextGenerator *final_dec, const string &key);
+  virtual TextGenerator *createGenerator(TextGenerator *final_dec,
+                                         const string &key);
   virtual DocGenerator *createDocGenerator();
 
   virtual CharTranslator *createCharTranslator() = 0;
@@ -57,7 +59,8 @@ class GeneratorFactory
     void decorate_generators();
 
  public:
-  GeneratorFactory(bool line_number, const string &t = "");
+  GeneratorFactory(bool line_number, const string &t = "",
+                   bool line_ref = false);
   virtual ~GeneratorFactory() {}
 
   virtual void createGenerators();
