@@ -37,6 +37,7 @@
 // globals
 #include "linenumdigit.h"
 #include "cmdlineargs.h"
+#include "scanner_map.h"
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -56,25 +57,14 @@ using std::cerr;
 using std::endl;
 using std::ofstream;
 
-extern int java_scanner_lex() ;
-extern int javascript_scanner_lex() ;
-extern int cpp_scanner_lex() ;
-extern int prolog_scanner_lex() ;
-extern int perl_scanner_lex() ;
-extern int php3_scanner_lex() ;
-extern int python_scanner_lex() ;
-extern int ruby_scanner_lex() ;
-extern int flex_scanner_lex() ;
-extern int changelog_scanner_lex() ;
-
 extern int tabSpaces; // FIXME
 
-static char *get_input_file_name(char *file_name);
+static char *get_input_file_name(const char *file_name);
 
 void
-processFile( char *source_language, char *output_format,
-             char *inputFileName, char *outputFileName,
-             short entire_doc )
+processFile( const char *source_language, const char *output_format,
+             const char *inputFileName, const char *outputFileName,
+             short entire_doc, bool gen_version )
 {
   FILE *in = 0;
   bool deleteOStream = false ;
@@ -107,7 +97,7 @@ processFile( char *source_language, char *output_format,
 
   if (inputFileName)
     {
-      char *input_file_name = get_input_file_name (inputFileName);
+      const char *input_file_name = get_input_file_name (inputFileName);
 
       in = freopen (input_file_name, "r", stdin);
       if (!in) 
@@ -132,6 +122,7 @@ processFile( char *source_language, char *output_format,
   }
 
   if ( entire_doc ) {
+    GlobalDocGenerator->set_gen_version (gen_version);
     GlobalDocGenerator->generate_top ();
   }
 
@@ -153,33 +144,37 @@ processFile( char *source_language, char *output_format,
   LineNumberDecorator::reset ();
 
   // decide which lexer to call
-  if (strcmp (source_language, "java") == 0)
-    java_scanner_lex () ;
-  else if (strcmp (source_language, "javascript") == 0)
-    javascript_scanner_lex () ;
-  else if (strcmp (source_language, "cpp") == 0)
-    cpp_scanner_lex ();
-  else if (strcmp (source_language, "prolog") == 0)
-    prolog_scanner_lex ();
-  else if (strcmp (source_language, "perl") == 0)
-    perl_scanner_lex ();
-  else if (strcmp (source_language, "php3") == 0)
-    php3_scanner_lex ();
-  else if (strcmp (source_language, "python") == 0)
-    python_scanner_lex ();
-  else if (strcmp (source_language, "ruby") == 0)
-    ruby_scanner_lex ();
-  else if (strcmp (source_language, "flex") == 0)
-    flex_scanner_lex ();
-  else if (strcmp (source_language, "changelog") == 0)
-    changelog_scanner_lex ();
+  ScannerMap scanner_map;
+
+  if (source_language)
+    {
+      if (! scanner_map.invoke_scanner (source_language))
+        {
+          cerr << PACKAGE << ": ";
+          cerr << "source language " << source_language 
+               << " not handled" << endl;
+          exit (1);
+        }
+    }
   else
     {
-      cerr << PACKAGE << ": ";
-      cerr << "source language " << source_language << " not handled" << endl;
-      exit (1);
+      string file_ext = get_file_extension (inputFileName);
+
+      if (file_ext == "")
+        {
+          cerr << PACKAGE << ": ";
+          cerr << "no file extension; please specify a source language" 
+               << endl;
+          exit (1);
+        }
+
+      if (! scanner_map.invoke_scanner (file_ext))
+        {
+          cerr << PACKAGE << ": ";
+          cerr << "unknown file extension " << file_ext << endl;
+          exit (1);
+        }
     }
-  // FIXME: a more object-oriented approach?
 
   GlobalDocGenerator->generate_end_doc ();
 
@@ -203,7 +198,7 @@ processFile( char *source_language, char *output_format,
 }
 
 char *
-get_input_file_name(char *file_name)
+get_input_file_name(const char *file_name)
 {
   unsigned int length = strlen (CHROOT_INPUT_DIR);
 
@@ -251,9 +246,32 @@ generate_normal	(const char *s)
 }
 
 void
-generateNewLine	(void)	
+generateNewLine	(const char *s)	
 {
-  generateln("");
+  if (s)
+    {
+      int len = strlen (s);
+      bool found_carriage_return = false;
+      for (int i = 0; i < len; ++i)
+        {
+          // before generating the real line break we generate all the
+          // other previous characters (probably \r)
+          if (s[i] == '\n')
+            generateln ("");
+          else
+            {
+              bool is_cr = (s[i] == '\r');
+              if (! is_cr || ! found_carriage_return)
+                generate(s, i, i); // a single character
+              if (is_cr)
+                found_carriage_return = true;
+              // we avoid to generate two consecutive \r that would
+              // result ugly (e.g., in html)
+            }
+        }
+    }
+  else
+    generateln("");
 }
 
 void
