@@ -1,8 +1,8 @@
 #ifndef GLOBALOSTREAM_H
 #define GLOBALOSTREAM_H
 
-#include <iostream.h>
+#include <iostream>
 
-extern ostream* sout;
+extern std::ostream* sout;
 
 #endif // GLOBALOSTREAM_H
