@@ -3,7 +3,11 @@
 #ifndef _MESSAGES_H
 #define _MESSAGES_H
 
-#include <iostream.h>
+#include <iostream>
+
+using std::ostream;
+using std::cerr;
+using std::endl;
 
 class Messages {
  public:
