@@ -27,7 +27,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- */                         
+ */
 
 #include <stdio.h>
 #include <string.h>
@@ -61,7 +61,7 @@ typedef union {
   char * string ; /* string : id, ... */
   int flag ;
   Tag *tag ;
-  Tags *tags ; 
+  Tags *tags ;
 } opsc_stype;
 # define YYSTYPE opsc_stype
 # define YYSTYPE_IS_TRIVIAL 1
@@ -130,8 +130,8 @@ static const short yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined. */
 static const short yyrline[] =
 {
-       0,    65,    67,    68,    71,    71,    83,    84,    87,    88,
-      89,    90
+       0,    65,    68,    69,    72,    72,    84,    85,    88,    89,
+      90,    91
 };
 #endif
 
@@ -916,15 +916,15 @@ case 3:
 { opsc_val.tags = new Tags() ; opsc_val.tags->AddTag( opsc_vsp[0].tag ) ;  }
     break;
 case 4:
-{ 
+{
                  printMessage( opsc_vsp[-1].string ) ;
                  printMessage( opsc_vsp[0].string ) ;
              }
     break;
 case 5:
-{ 
-	       opsc_val.tag = new Tag( strdup(opsc_vsp[-4].string), strdup(opsc_vsp[-3].string) ) ;
-               opsc_val.tag->SetFlags(opsc_vsp[-1].flag) ; 
+{
+	       opsc_val.tag = new Tag( opsc_vsp[-4].string, opsc_vsp[-3].string ) ;
+               opsc_val.tag->SetFlags(opsc_vsp[-1].flag) ;
 	     }
     break;
 case 6:
@@ -1211,7 +1211,7 @@ FILE *
 openTagsFile()
 {
   FILE *file = 0;
-  
+
   printMessage( "Trying with..." ) ;
 
   if ( tags_file )
@@ -1221,7 +1221,7 @@ openTagsFile()
       if (file)
         return file;
     }
-  
+
   printMessage( TAGS_FILE ) ;
   file = fopen( TAGS_FILE, "r") ;
   if ( file )
@@ -1229,15 +1229,15 @@ openTagsFile()
 
   file = fopen( SOURCE_HIGHLIGHT_DATA_DIR "/" TAGS_FILE, "r") ;
   printMessage( SOURCE_HIGHLIGHT_DATA_DIR "/" TAGS_FILE ) ;
-  
+
   return file ;
 }
 
-void 
-opsc_error( char *s ) 
+void
+opsc_error( char *s )
 {
   ostringstream str ;
-  str << "*** " << s << " on option # " << line; 
+  str << "*** " << s << " on option # " << line;
   printError( str.str().c_str(), cerr ) ;
   printError( "Using default tags...", cerr ) ;
 }
